@@ -217,6 +217,14 @@ def sync(
     is_flag=True,
     help="Include notes from trash into export.",
 )
+@click.option(
+    "--no-export-date",
+    is_flag=True,
+    help=(
+        "Don't timestamp exported enex files."
+        " (e.g. to prevent backup chunking with zero changes)"
+    ),
+)
 @click.argument(
     "output_path",
     required=True,
@@ -226,6 +234,7 @@ def export(
     database: str,
     single_notes: bool,
     include_trash: bool,
+    no_export_date: bool,
     output_path: str,
 ) -> None:
     """Export all notes from local database into ENEX files."""
@@ -234,6 +243,7 @@ def export(
         database=database,
         single_notes=single_notes,
         include_trash=include_trash,
+        no_export_date=no_export_date,
         output_path=output_path,
     )
 
